@@ -34,7 +34,7 @@
 class SegSites : public SummaryStatistic
 {
  public:
-  SegSites() { set_position(0.0); }
+  SegSites( ) { set_position(0.0); set_transpose(false);}
   ~SegSites() {}
 
 #ifdef UNITTEST
@@ -44,6 +44,7 @@ class SegSites : public SummaryStatistic
   //Virtual methods
   void calculate(const Forest &forest);
   void printLocusOutput(std::ostream &output) const;
+
   SegSites* clone() const { return new SegSites(*this); }
 
   void clear() { 
@@ -60,16 +61,20 @@ class SegSites : public SummaryStatistic
   std::valarray<bool> const* getHaplotype(const size_t mutation) const {
     return &(haplotypes_.at(mutation));
   }
+  void set_transpose(const bool transpose) { transpose_ = transpose; };
+  bool get_transpose() const { return transpose_; }
 
  private:
   std::valarray<bool> getHaplotypes(TreePoint mutation, const Forest &Forest); 
 
   std::vector<double> positions_;
+  std::vector<double> heights_;
   std::vector<std::valarray<bool>> haplotypes_;	
   void traversal(Node const* node, std::valarray<bool> &haplotype) const;
 
   void set_position(const double position) { position_ = position; };
   double position_;
+  bool transpose_;
 };
 
 #endif
